# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-28 01:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course_simple', '0024_userpart_question_correct_count'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserPartNote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('note', models.TextField(verbose_name='\u5b66\u4e60\u7b14\u8bb0')),
                ('is_open', models.BooleanField(default=True, verbose_name='\u516c\u5f00\u7b14\u8bb0')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('is_stick', models.BooleanField(default=False, verbose_name='\u662f\u5426\u7f6e\u9876')),
                ('is_digest', models.BooleanField(default=False, verbose_name='\u662f\u5426\u7cbe\u534e')),
                ('part', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_course_simple.Part')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_course_simple_userpartnote',
                'verbose_name': '\u7528\u6237\u7b14\u8bb0',
            },
        ),
    ]



# -*- coding:utf-8 -*-
__author__ = 'bee'
from django.dispatch import Signal
# 完成答题后，发出的奖励信号
add_prize_coin = Signal(providing_args=["user", "coin", "reason"])

# 小节视频写笔记
user_part_note_created = Signal(providing_args=['user_part_note_id'])